{% load redsolutioncms_tags %}{% raw %}{% extends "easy_news/base.html" %} {% load i18n %} {% endraw %} {% if easy_news_settings.seo_was_installed %}{% raw %} {% load seo_tags %} {% block title %}{% seo title as title %}{% if title %}{{ title }}{% else %}{% trans 'Last news' %}{% endif %}{% endblock %} {% endraw %}{% else %}{% raw %} {% block title %}{% trans 'Last news' %}{% endblock %} {% endraw %}{% endif %}{% raw %} {% block content_title %}{% trans 'Last news' %}{% endblock %} {% block content %} {% include "easy_news/news_include.html" %}
{% for date in date_list %}
{{ date|date:"Y" }}
{% endfor %}
{% trans 'All news' %}
{% endblock %} {% endraw %}{% if easy_news_settings.menu_proxy_was_installed %} {% raw %}{% load menuproxy_tags %}{% endraw %} {% if easy_news_settings.show_archive %}{% raw %} {% block main_menu %}{% show_main_menu 'news_archive' %}{% endblock %} {% block auto_menu %}{% show_auto_menu 'news_archive' %}{% endblock %} {% block full_menu %}{% show_full_menu 'news_archive' %}{% endblock %} {% block breadcrumbs %}{% show_breadcrumbs 'news_archive' %}{% endblock %} {% endraw %}{% else %}{% raw %} {% block main_menu %}{% show_main_menu 'news_list' %}{% endblock %} {% block auto_menu %}{% show_auto_menu 'news_list' %}{% endblock %} {% block full_menu %}{% show_full_menu 'news_list' %}{% endblock %} {% block breadcrumbs %}{% show_breadcrumbs 'news_list' %}{% endblock %} {% endraw %}{% endif %}{% endif %}